@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 use File::Copy;
 use File::Path;
@@ -77,6 +77,7 @@ cp rmf mkd cd make
 cdback download untar 
 pie slurp blurt mv tap 
 plough qquote quote perm_cp
+perm_get perm_set
 sysrun untar_in pick ask
 hammer say
 sudo_me bin_find
@@ -866,7 +867,7 @@ sub tap {
         $cmd = join ' ', map { qquote($_, ":shell") } @args;
     } else {
             # Default mode: Single quotes
-        $cmd = join ' ', map { quote($_) } @args;
+        $cmd = join ' ', map { quote($_, ":shell") } @args;
     }
        
     $cmd = "$cmd 2>$tmpfile |";
@@ -881,6 +882,8 @@ sub tap {
 
     my $stderr = slurp($tmpfile);
 
+    DEBUG "tap $cmd results: rc=$exit_code stderr=[$stderr] stdout=[$stdout]";
+
     return ($stdout, $stderr, $exit_code);
 }
 
